@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,7 +36,7 @@
 
 #include <cstring>
 
-#include "Util.h"
+#include "util.h"
 #include "BtConstants.h"
 #include "a2functional.h"
 
@@ -45,7 +45,7 @@ namespace aria2 {
 const std::string BtHandshakeMessage::NAME("handshake");
 
 const unsigned char* BtHandshakeMessage::BT_PSTR =
-  (const unsigned char*)"BitTorrent protocol";
+  reinterpret_cast<const unsigned char*>("BitTorrent protocol");
 
 BtHandshakeMessage::BtHandshakeMessage():SimpleBtMessage(ID, NAME)
 {
@@ -53,7 +53,7 @@ BtHandshakeMessage::BtHandshakeMessage():SimpleBtMessage(ID, NAME)
 }
 
 BtHandshakeMessage::BtHandshakeMessage(const unsigned char* infoHash,
-				       const unsigned char* peerId):
+                                       const unsigned char* peerId):
   SimpleBtMessage(ID, NAME)
 {
   init();
@@ -62,7 +62,6 @@ BtHandshakeMessage::BtHandshakeMessage(const unsigned char* infoHash,
 }
 
 void BtHandshakeMessage::init() {
-  msg = 0;
   this->pstrlen = 19;
   pstr = new unsigned char[PSTR_LENGTH];
   reserved = new unsigned char[RESERVED_LENGTH];
@@ -88,15 +87,14 @@ BtHandshakeMessage::create(const unsigned char* data, size_t dataLength)
   return message;
 }
 
-const unsigned char* BtHandshakeMessage::getMessage() {
-  if(!msg) {
-    msg = new unsigned char[MESSAGE_LENGTH];
-    msg[0] = pstrlen;
-    memcpy(msg+1, pstr, PSTR_LENGTH);
-    memcpy(msg+20, reserved, RESERVED_LENGTH);
-    memcpy(msg+28, infoHash, INFO_HASH_LENGTH);
-    memcpy(msg+48, peerId, PEER_ID_LENGTH);
-  }
+unsigned char* BtHandshakeMessage::createMessage()
+{
+  unsigned char* msg = new unsigned char[MESSAGE_LENGTH];
+  msg[0] = pstrlen;
+  memcpy(msg+1, pstr, PSTR_LENGTH);
+  memcpy(msg+20, reserved, RESERVED_LENGTH);
+  memcpy(msg+28, infoHash, INFO_HASH_LENGTH);
+  memcpy(msg+48, peerId, PEER_ID_LENGTH);
   return msg;
 }
 
@@ -106,9 +104,9 @@ size_t BtHandshakeMessage::getMessageLength() {
 
 std::string BtHandshakeMessage::toString() const {
   return strconcat(NAME, " peerId=",
-		   Util::urlencode(peerId, PEER_ID_LENGTH),
-		   ", reserved=",
-		   Util::toHex(reserved, RESERVED_LENGTH));
+                   util::percentEncode(peerId, PEER_ID_LENGTH),
+                   ", reserved=",
+                   util::toHex(reserved, RESERVED_LENGTH));
 }
 
 bool BtHandshakeMessage::isFastExtensionSupported() const {
