@@ -37,7 +37,7 @@
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 
 namespace aria2 {
 
@@ -72,9 +72,9 @@ private:
 
   size_t _numRetry;
 
-  Time _lastGetPeerTime;
+  Timer _lastGetPeerTime;
 public:
-  DHTGetPeersCommand(int32_t cuid, RequestGroup* requestGroup,
+  DHTGetPeersCommand(cuid_t cuid, RequestGroup* requestGroup,
                      DownloadEngine* e);
 
   virtual ~DHTGetPeersCommand();
