@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -58,10 +58,11 @@ const std::string DHTGetPeersReplyMessage::VALUES("values");
 
 const std::string DHTGetPeersReplyMessage::NODES("nodes");
 
-DHTGetPeersReplyMessage::DHTGetPeersReplyMessage(const SharedHandle<DHTNode>& localNode,
-						 const SharedHandle<DHTNode>& remoteNode,
-						 const std::string& token,
-						 const std::string& transactionID):
+DHTGetPeersReplyMessage::DHTGetPeersReplyMessage
+(const SharedHandle<DHTNode>& localNode,
+ const SharedHandle<DHTNode>& remoteNode,
+ const std::string& token,
+ const std::string& transactionID):
   DHTResponseMessage(localNode, remoteNode, transactionID),
   _token(token) {}
 
@@ -80,37 +81,46 @@ BDE DHTGetPeersReplyMessage::getResponse()
   if(_values.empty()) {
     size_t offset = 0;
     unsigned char buffer[DHTBucket::K*26];
-    for(std::deque<SharedHandle<DHTNode> >::const_iterator i =
-	  _closestKNodes.begin();
-	i != _closestKNodes.end() && offset < DHTBucket::K*26; ++i) {
+    for(std::vector<SharedHandle<DHTNode> >::const_iterator i =
+          _closestKNodes.begin(), eoi = _closestKNodes.end();
+        i != eoi && offset < DHTBucket::K*26; ++i) {
       SharedHandle<DHTNode> node = *i;
       memcpy(buffer+offset, node->getID(), DHT_ID_LENGTH);
       if(bittorrent::createcompact
-	 (buffer+20+offset, node->getIPAddress(), node->getPort())) {
-	offset += 26;
+         (buffer+20+offset, node->getIPAddress(), node->getPort())) {
+        offset += 26;
       }
     }
     rDict[NODES] = BDE(buffer, offset);
   } else {
-    // Limit the size of values list.  The maxmum payload size of UDP
-    // packet is limited to 65507bytes.  aria2 uses 20bytes token and
-    // 2byte transaction ID. The size of get_peers reply message
-    // without values list is 87bytes:
+    // Limit the size of values list.  The maxmum size of UDP datagram
+    // is limited to 65535 bytes. aria2 uses 20bytes token and 2byte
+    // transaction ID. The size of get_peers reply message without
+    // values list is 87bytes:
     //
     // d1:rd2:id20:aaaaaaaaaaaaaaaaaaaa5:token20:aaaaaaaaaaaaaaaaaaaa
     // 6:valueslee1:t2:bb1:y1:re
     //
-    // With this configuration, We can send (65507-87)/8 = 8177
-    // values.  Since the size of token and transaction ID may vary in
-    // implementations, we use 8100.
-    static const size_t MAX_VALUES_SIZE = 8100;
+    // Because of Path MTU Discovery, UDP packet size which need not
+    // to be fragmented is much smaller. Since Linux uses Path MTU
+    // Dicoverry by default and returning ICMP message might be
+    // filtered, we should avoid fragmentation.  MTU of pppoe is 1492
+    // max according to RFC2516.  We use maximum packet size to be
+    // 1000. Since it contains 20 bytes IP header and 8 bytes UDP
+    // header and 87 bytes reply message template described above, We
+    // can carry (1000-28-87)/8 = 110 peer info. Since DHT spec
+    // doesn't specify the maximum size of token, reply message
+    // template may get bigger than 87 bytes. So we use 100 as maximum
+    // number of peer info that a message can carry.
+    static const size_t MAX_VALUES_SIZE = 100;
     BDE valuesList = BDE::list();
-    for(std::deque<SharedHandle<Peer> >::const_iterator i = _values.begin();
-	i != _values.end() && valuesList.size() < MAX_VALUES_SIZE; ++i) {
+    for(std::vector<SharedHandle<Peer> >::const_iterator i = _values.begin(),
+          eoi = _values.end(); i != eoi && valuesList.size() < MAX_VALUES_SIZE;
+        ++i) {
       const SharedHandle<Peer>& peer = *i;
       unsigned char buffer[6];
       if(bittorrent::createcompact(buffer, peer->ipaddr, peer->port)) {
-	valuesList << BDE(buffer, sizeof(buffer));
+        valuesList << BDE(buffer, sizeof(buffer));
       }
     }
     rDict[VALUES] = valuesList;
@@ -125,21 +135,11 @@ std::string DHTGetPeersReplyMessage::getMessageType() const
 
 void DHTGetPeersReplyMessage::validate() const {}
 
-void DHTGetPeersReplyMessage::setClosestKNodes(const std::deque<SharedHandle<DHTNode> >& closestKNodes)
-{
-  _closestKNodes = closestKNodes;
-}
-
-void DHTGetPeersReplyMessage::setValues(const std::deque<SharedHandle<Peer> >& peers)
-{
-  _values = peers;
-}
-
 std::string DHTGetPeersReplyMessage::toStringOptional() const
 {
   return strconcat("token=", util::toHex(_token),
-		   ", values=", util::uitos(_values.size()),
-		   ", nodes=", util::uitos(_closestKNodes.size()));
+                   ", values=", util::uitos(_values.size()),
+                   ", nodes=", util::uitos(_closestKNodes.size()));
 }
 
 } // namespace aria2
