@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,11 +39,12 @@
 
 #include  <limits.h>
 
-#include "TimeA2.h"
+#include "TimerA2.h"
+#include "Command.h"
 
 namespace aria2 {
 
-class BtContext;
+class DownloadContext;
 class BtRuntime;
 class PieceStorage;
 class PeerStorage;
@@ -59,6 +60,8 @@ class ExtensionMessageRegistry;
 class DHTNode;
 class Logger;
 class RequestGroupMan;
+class UTMetadataRequestFactory;
+class UTMetadataRequestTracker;
 
 class FloodingStat {
 private:
@@ -95,9 +98,9 @@ public:
 
 class DefaultBtInteractive : public BtInteractive {
 private:
-  int32_t cuid;
+  cuid_t cuid;
 
-  SharedHandle<BtContext> _btContext;
+  SharedHandle<DownloadContext> _downloadContext;
 
   SharedHandle<BtRuntime> _btRuntime;
 
@@ -114,24 +117,30 @@ private:
   SharedHandle<BtMessageFactory> messageFactory;
   SharedHandle<ExtensionMessageFactory> _extensionMessageFactory;
   SharedHandle<ExtensionMessageRegistry> _extensionMessageRegistry;
+  SharedHandle<UTMetadataRequestFactory> _utMetadataRequestFactory;
+  SharedHandle<UTMetadataRequestTracker> _utMetadataRequestTracker;
+
+  bool _metadataGetMode;
 
   WeakHandle<DHTNode> _localNode;
 
   Logger* logger;
   size_t allowedFastSetSize;
-  Time haveCheckPoint;
-  Time keepAliveCheckPoint;
-  Time floodingCheckPoint;
+  Timer haveTimer;
+  Timer keepAliveTimer;
+  Timer floodingTimer;
   FloodingStat floodingStat;
-  Time inactiveCheckPoint;
-  Time _pexCheckPoint;
-  Time _perSecCheckPoint;
+  Timer inactiveTimer;
+  Timer _pexTimer;
+  Timer _perSecTimer;
   time_t keepAliveInterval;
   bool _utPexEnabled;
   bool _dhtEnabled;
 
   size_t _numReceivedMessage;
 
+  size_t _maxOutstandingRequest;
+
   WeakHandle<RequestGroupMan> _requestGroupMan;
 
   static const time_t FLOODING_CHECK_INTERVAL = 5;
@@ -151,8 +160,8 @@ private:
   void addPortMessageToQueue();
 
 public:
-  DefaultBtInteractive(const SharedHandle<BtContext>& btContext,
-		       const SharedHandle<Peer>& peer);
+  DefaultBtInteractive(const SharedHandle<DownloadContext>& downloadContext,
+                       const SharedHandle<Peer>& peer);
 
   virtual ~DefaultBtInteractive();
 
@@ -180,7 +189,8 @@ public:
 
   virtual size_t countOutstandingRequest();
 
-  void setCuid(int32_t cuid) {
+  void setCuid(cuid_t cuid)
+  {
     this->cuid = cuid;
   }
 
@@ -228,6 +238,23 @@ public:
   }
 
   void setRequestGroupMan(const WeakHandle<RequestGroupMan>& rgman);
+
+  void setUTMetadataRequestTracker
+  (const SharedHandle<UTMetadataRequestTracker>& tracker)
+  {
+    _utMetadataRequestTracker = tracker;
+  }
+
+  void setUTMetadataRequestFactory
+  (const SharedHandle<UTMetadataRequestFactory>& factory)
+  {
+    _utMetadataRequestFactory = factory;
+  }
+
+  void enableMetadataGetMode()
+  {
+    _metadataGetMode = true;
+  }
 };
 
 typedef SharedHandle<DefaultBtInteractive> DefaultBtInteractiveHandle;
