@@ -48,11 +48,12 @@
 #include "prefs.h"
 #include "A2STR.h"
 #include "DownloadContext.h"
+#include "util.h"
 
 namespace aria2 {
 
 HttpInitiateConnectionCommand::HttpInitiateConnectionCommand
-(int cuid,
+(cuid_t cuid,
  const SharedHandle<Request>& req,
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
@@ -69,10 +70,14 @@ Command* HttpInitiateConnectionCommand::createNextCommand
   Command* command;
   if(!proxyRequest.isNull()) {
     SharedHandle<SocketCore> pooledSocket =
-      e->popPooledSocket(req->getHost(), req->getPort());
+      e->popPooledSocket(req->getHost(), req->getPort(),
+                         proxyRequest->getHost(), proxyRequest->getPort());
     std::string proxyMethod = resolveProxyMethod(req->getProtocol());
     if(pooledSocket.isNull()) {
-      logger->info(MSG_CONNECTING_TO_SERVER, cuid, addr.c_str(), port);
+      if(logger->info()) {
+        logger->info(MSG_CONNECTING_TO_SERVER,
+                     util::itos(cuid).c_str(), addr.c_str(), port);
+      }
       socket.reset(new SocketCore());
       socket->establishConnection(addr, port);
 
@@ -115,7 +120,10 @@ Command* HttpInitiateConnectionCommand::createNextCommand
     SharedHandle<SocketCore> pooledSocket =
       e->popPooledSocket(resolvedAddresses, req->getPort());
     if(pooledSocket.isNull()) {
-      logger->info(MSG_CONNECTING_TO_SERVER, cuid, addr.c_str(), port);
+      if(logger->info()) {
+        logger->info(MSG_CONNECTING_TO_SERVER,
+                     util::itos(cuid).c_str(), addr.c_str(), port);
+      }
       socket.reset(new SocketCore());
       socket->establishConnection(addr, port);
     } else {
