@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -61,14 +61,14 @@ private:
 protected:
   virtual bool executeInternal();
 public:
-  HttpSkipResponseCommand(int cuid,
-			  const SharedHandle<Request>& req,
-			  const SharedHandle<FileEntry>& fileEntry,
-			  RequestGroup* requestGroup,
-			  const SharedHandle<HttpConnection>& httpConnection,
-			  const SharedHandle<HttpResponse>& httpResponse,
-			  DownloadEngine* e,
-			  const SharedHandle<SocketCore>& s);
+  HttpSkipResponseCommand(cuid_t cuid,
+                          const SharedHandle<Request>& req,
+                          const SharedHandle<FileEntry>& fileEntry,
+                          RequestGroup* requestGroup,
+                          const SharedHandle<HttpConnection>& httpConnection,
+                          const SharedHandle<HttpResponse>& httpResponse,
+                          DownloadEngine* e,
+                          const SharedHandle<SocketCore>& s);
 
   virtual ~HttpSkipResponseCommand();
 
