@@ -38,7 +38,6 @@
 #include "common.h"
 
 #include <string>
-#include <deque>
 #include <vector>
 #include <iosfwd>
 
@@ -69,7 +68,7 @@ public:
   // Parses options in argv and writes option name and value to out in
   // NAME=VALUE format. Non-option strings are stored in nonopts.
   // Throws Exception when an unrecognized option is found.
-  void parseArg(std::ostream& out, std::deque<std::string>& nonopts,
+  void parseArg(std::ostream& out, std::vector<std::string>& nonopts,
                 int argc, char* const argv[]);
 
   void parse(Option& option, std::istream& ios);
@@ -102,7 +101,7 @@ public:
   // Hidden options are not returned.
   SharedHandle<OptionHandler> findByShortName(char shortName) const;
 
-  static SharedHandle<OptionParser> getInstance();
+  static const SharedHandle<OptionParser>& getInstance();
 };
 
 typedef SharedHandle<OptionParser> OptionParserHandle;
