@@ -35,7 +35,6 @@
 #include "PeerListenCommand.h"
 
 #include <utility>
-#include <deque>
 #include <algorithm>
 
 #include "DownloadEngine.h"
@@ -48,6 +47,7 @@
 #include "Socket.h"
 #include "SimpleRandomizer.h"
 #include "FileEntry.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -55,7 +55,7 @@ unsigned int PeerListenCommand::__numInstance = 0;
 
 PeerListenCommand* PeerListenCommand::__instance = 0;
 
-PeerListenCommand::PeerListenCommand(int32_t cuid, DownloadEngine* e):
+PeerListenCommand::PeerListenCommand(cuid_t cuid, DownloadEngine* e):
   Command(cuid),
   e(e),
   _lowestSpeedLimit(20*1024)
@@ -72,12 +72,12 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
 {
   socket.reset(new SocketCore());
 
-  std::deque<int32_t> randPorts = seq.flush();
+  std::vector<int32_t> randPorts = seq.flush();
   std::random_shuffle(randPorts.begin(), randPorts.end(),
                       *SimpleRandomizer::getInstance().get());
   
-  for(std::deque<int32_t>::const_iterator portItr = randPorts.begin();
-      portItr != randPorts.end(); ++portItr) {
+  for(std::vector<int32_t>::const_iterator portItr = randPorts.begin(),
+        eoi = randPorts.end(); portItr != eoi; ++portItr) {
     if(!(0 < (*portItr) && (*portItr) <= 65535)) {
       continue;
     }
@@ -89,7 +89,7 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
       logger->notice("BitTorrent: listening to port %d", port);
       return true;
     } catch(RecoverableException& ex) {
-      logger->error(MSG_BIND_FAILURE, ex, cuid, port);
+      logger->error(MSG_BIND_FAILURE, ex, util::itos(cuid).c_str(), port);
       socket->closeConnection();
     }
   }
@@ -120,8 +120,8 @@ bool PeerListenCommand::execute() {
 
       peerSocket->setNonBlockingMode();
 
-      PeerHandle peer(new Peer(peerInfo.first, peerInfo.second, true));
-      int32_t cuid = e->newCUID();
+      SharedHandle<Peer> peer(new Peer(peerInfo.first, peerInfo.second, true));
+      cuid_t cuid = e->newCUID();
       Command* command =
         new ReceiverMSEHandshakeCommand(cuid, peer, e, peerSocket);
       e->commands.push_back(command);
@@ -129,11 +129,11 @@ bool PeerListenCommand::execute() {
         logger->debug("Accepted the connection from %s:%u.",
                       peer->ipaddr.c_str(),
                       peer->port);
-        logger->debug("Added CUID#%d to receive BitTorrent/MSE handshake.",
-                      cuid);
+        logger->debug("Added CUID#%s to receive BitTorrent/MSE handshake.",
+                      util::itos(cuid).c_str());
       }
     } catch(RecoverableException& ex) {
-      logger->debug(MSG_ACCEPT_FAILURE, ex, cuid);
+      logger->debug(MSG_ACCEPT_FAILURE, ex, util::itos(cuid).c_str());
     }               
   }
   e->commands.push_back(this);
