@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -40,15 +40,16 @@
 #include <string>
 #include <deque>
 #include <iosfwd>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "DownloadResult.h"
 #include "TransferStat.h"
+#include "RequestGroup.h"
 
 namespace aria2 {
 
 class DownloadEngine;
-class RequestGroup;
 class Command;
 class Logger;
 class DownloadResult;
@@ -63,7 +64,6 @@ private:
   std::deque<SharedHandle<DownloadResult> > _downloadResults;
   Logger* _logger;
   unsigned int _maxSimultaneousDownloads;
-  int32_t _gidCounter;
 
   const Option* _option;
 
@@ -76,16 +76,18 @@ private:
   // truf if XML-RPC is enabled.
   bool _xmlRpc;
 
+  bool _queueCheck;
+
   std::string
   formatDownloadResult(const std::string& status,
-		       const SharedHandle<DownloadResult>& downloadResult) const;
+                       const SharedHandle<DownloadResult>& downloadResult) const;
 
   void configureRequestGroup
   (const SharedHandle<RequestGroup>& requestGroup) const;
 public:
-  RequestGroupMan(const std::deque<SharedHandle<RequestGroup> >& requestGroups,
-		  unsigned int maxSimultaneousDownloads,
-		  const Option* option);
+  RequestGroupMan(const std::vector<SharedHandle<RequestGroup> >& requestGroups,
+                  unsigned int maxSimultaneousDownloads,
+                  const Option* option);
 
   bool downloadFinished();
 
@@ -103,17 +105,17 @@ public:
 
   void addRequestGroup(const SharedHandle<RequestGroup>& group);
 
-  void addReservedGroup(const std::deque<SharedHandle<RequestGroup> >& groups);
+  void addReservedGroup(const std::vector<SharedHandle<RequestGroup> >& groups);
 
   void addReservedGroup(const SharedHandle<RequestGroup>& group);
 
   void insertReservedGroup
-  (size_t pos, const std::deque<SharedHandle<RequestGroup> >& groups);
+  (size_t pos, const std::vector<SharedHandle<RequestGroup> >& groups);
 
   void insertReservedGroup(size_t pos, const SharedHandle<RequestGroup>& group);
 
   size_t countRequestGroup() const;
-		  
+                  
   SharedHandle<RequestGroup> getRequestGroup(size_t index) const;
   
   const std::deque<SharedHandle<RequestGroup> >& getRequestGroups() const
@@ -121,16 +123,33 @@ public:
     return _requestGroups;
   }
 
-  SharedHandle<RequestGroup> findRequestGroup(int32_t gid) const;
+  SharedHandle<RequestGroup> findRequestGroup(gid_t gid) const;
 
   const std::deque<SharedHandle<RequestGroup> >& getReservedGroups() const
   {
     return _reservedGroups;
   }
 
-  SharedHandle<RequestGroup> findReservedGroup(int32_t gid) const;
+  SharedHandle<RequestGroup> findReservedGroup(gid_t gid) const;
 
-  bool removeReservedGroup(int32_t gid);
+  enum HOW {
+    POS_SET,
+    POS_CUR,
+    POS_END
+  };
+
+  // Changes the position of download denoted by gid.  If how is
+  // POS_SET, it moves the download to a position relative to the
+  // beginning of the queue.  If how is POS_CUR, it moves the download
+  // to a position relative to the current position. If how is
+  // POS_END, it moves the download to a position relative to the end
+  // of the queue. If the destination position is less than 0 or
+  // beyond the end of the queue, it moves the download to the
+  // beginning or the end of the queue respectively.  Returns the
+  // destination position.
+  size_t changeReservedGroupPosition(gid_t gid, int pos, HOW how);
+
+  bool removeReservedGroup(gid_t gid);
 
   void showDownloadResults(std::ostream& o) const;
 
@@ -147,11 +166,11 @@ public:
     downloadresultcode::RESULT _lastErrorResult;
   public:
     DownloadStat(size_t completed,
-		 size_t error,
-		 size_t inProgress,
-		 size_t waiting,
-		 downloadresultcode::RESULT lastErrorResult =
-		 downloadresultcode::FINISHED):
+                 size_t error,
+                 size_t inProgress,
+                 size_t waiting,
+                 downloadresultcode::RESULT lastErrorResult =
+                 downloadresultcode::FINISHED):
       _completed(completed),
       _error(error),
       _inProgress(inProgress),
@@ -181,16 +200,16 @@ public:
     return _downloadResults;
   }
 
-  SharedHandle<DownloadResult> findDownloadResult(int32_t gid) const;
+  SharedHandle<DownloadResult> findDownloadResult(gid_t gid) const;
 
   // Removes all download results.
   void purgeDownloadResult();
 
   SharedHandle<ServerStat> findServerStat(const std::string& hostname,
-					  const std::string& protocol) const;
+                                          const std::string& protocol) const;
 
   SharedHandle<ServerStat> getOrCreateServerStat(const std::string& hostname,
-						 const std::string& protocol);
+                                                 const std::string& protocol);
 
   bool addServerStat(const SharedHandle<ServerStat>& serverStat);
 
@@ -236,6 +255,24 @@ public:
   {
     _maxSimultaneousDownloads = max;
   }
+
+  // Call this function if _requestGroups queue should be maintained.
+  // This function is added to reduce the call of maintenance, but at
+  // the same time, it provides fast maintenance reaction.
+  void requestQueueCheck()
+  {
+    _queueCheck = true;
+  }
+
+  void clearQueueCheck()
+  {
+    _queueCheck = false;
+  }
+
+  bool queueCheckRequested() const
+  {
+    return _queueCheck;
+  }
 };
 
 typedef SharedHandle<RequestGroupMan> RequestGroupManHandle;
