@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,9 +38,10 @@
 #include <ostream>
 #include <iterator>
 #include <map>
+#include <vector>
 
 #include "ServerStat.h"
-#include "Util.h"
+#include "util.h"
 #include "RecoverableException.h"
 
 namespace aria2 {
@@ -50,7 +51,7 @@ ServerStatMan::ServerStatMan() {}
 ServerStatMan::~ServerStatMan() {}
 
 SharedHandle<ServerStat> ServerStatMan::find(const std::string& hostname,
-					     const std::string& protocol) const
+                                             const std::string& protocol) const
 {
   SharedHandle<ServerStat> ss(new ServerStat(hostname, protocol));
   std::deque<SharedHandle<ServerStat> >::const_iterator i =
@@ -79,7 +80,7 @@ bool ServerStatMan::add(const SharedHandle<ServerStat>& serverStat)
 bool ServerStatMan::save(std::ostream& out) const
 {
   std::copy(_serverStats.begin(), _serverStats.end(),
-	    std::ostream_iterator<SharedHandle<ServerStat> >(out, "\n"));
+            std::ostream_iterator<SharedHandle<ServerStat> >(out, "\n"));
   out.flush();
   return !out.bad();
 }
@@ -97,18 +98,18 @@ bool ServerStatMan::load(std::istream& in)
 
   std::string line;
   while(getline(in, line)) {
-    Util::trimSelf(line);
+    util::trimSelf(line);
     if(line.empty()) {
       continue;
     }
-    std::deque<std::string> items;
-    Util::slice(items, line, ',');
+    std::vector<std::string> items;
+    util::split(line, std::back_inserter(items), ",");
     std::map<std::string, std::string> m;
-    for(std::deque<std::string>::const_iterator i = items.begin();
-	i != items.end(); ++i) {
-      std::pair<std::string, std::string> p = Util::split(*i, "=");
-      Util::trimSelf(p.first);
-      Util::trimSelf(p.second);
+    for(std::vector<std::string>::const_iterator i = items.begin(),
+          eoi = items.end(); i != eoi; ++i) {
+      std::pair<std::string, std::string> p = util::split(*i, "=");
+      util::trimSelf(p.first);
+      util::trimSelf(p.second);
       m[p.first] = p.second;
     }
     if(m[S_HOST].empty() || m[S_PROTOCOL].empty()) {
@@ -116,20 +117,20 @@ bool ServerStatMan::load(std::istream& in)
     }
     SharedHandle<ServerStat> sstat(new ServerStat(m[S_HOST], m[S_PROTOCOL]));
     try {
-      sstat->setDownloadSpeed(Util::parseUInt(m[S_DL_SPEED]));
+      sstat->setDownloadSpeed(util::parseUInt(m[S_DL_SPEED]));
       // Old serverstat file doesn't contains SC_AVG_SPEED
       if(m.find(S_SC_AVG_SPEED) != m.end()) {
-	sstat->setSingleConnectionAvgSpeed(Util::parseUInt(m[S_SC_AVG_SPEED]));
+        sstat->setSingleConnectionAvgSpeed(util::parseUInt(m[S_SC_AVG_SPEED]));
       }
       // Old serverstat file doesn't contains MC_AVG_SPEED
       if(m.find(S_MC_AVG_SPEED) != m.end()) {
-	sstat->setMultiConnectionAvgSpeed(Util::parseUInt(m[S_MC_AVG_SPEED]));
+        sstat->setMultiConnectionAvgSpeed(util::parseUInt(m[S_MC_AVG_SPEED]));
       }
       // Old serverstat file doesn't contains COUNTER_SPEED
       if(m.find(S_COUNTER) != m.end()) {
-	sstat->setCounter(Util::parseUInt(m[S_COUNTER]));
+        sstat->setCounter(util::parseUInt(m[S_COUNTER]));
       }
-      sstat->setLastUpdated(Time(Util::parseInt(m[S_LAST_UPDATED])));
+      sstat->setLastUpdated(Time(util::parseInt(m[S_LAST_UPDATED])));
       sstat->setStatus(m[S_STATUS]);
       add(sstat);
     } catch(RecoverableException& e) {
@@ -142,20 +143,21 @@ bool ServerStatMan::load(std::istream& in)
 class FindStaleServerStat {
 private:
   time_t _timeout;
+  Time _time;
 public:
   FindStaleServerStat(time_t timeout):_timeout(timeout) {}
 
   bool operator()(const SharedHandle<ServerStat>& ss) const
   {
-    return ss->getLastUpdated().elapsed(_timeout);
+    return ss->getLastUpdated().difference(_time) >= _timeout;
   }
 };
 
 void ServerStatMan::removeStaleServerStat(time_t timeout)
 {
   _serverStats.erase(std::remove_if(_serverStats.begin(), _serverStats.end(),
-				    FindStaleServerStat(timeout)),
-		     _serverStats.end());
+                                    FindStaleServerStat(timeout)),
+                     _serverStats.end());
 }
 
 } // namespace aria2
