@@ -37,6 +37,7 @@
 #include "Peer.h"
 #include "PeerConnection.h"
 #include "Logger.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -53,18 +54,20 @@ void SimpleBtMessage::send() {
     return;
   }
   if(!sendingInProgress) {
-    const unsigned char* msg = getMessage();
+    if(logger->info()) {
+      logger->info(MSG_SEND_PEER_MESSAGE,
+                   util::itos(cuid).c_str(),
+                   peer->ipaddr.c_str(), peer->port, toString().c_str());
+    }
+    unsigned char* msg = createMessage();
     size_t msgLength = getMessageLength();
-    logger->info(MSG_SEND_PEER_MESSAGE,
-                 cuid, peer->ipaddr.c_str(), peer->port, toString().c_str());
     if(logger->debug()) {
       logger->debug("msglength = %lu bytes",
                     static_cast<unsigned long>(msgLength));
     }
-    peerConnection->sendMessage(msg, msgLength);
-  } else {
-    peerConnection->sendPendingData();
+    peerConnection->pushBytes(msg, msgLength);
   }
+  peerConnection->sendPendingData();
   sendingInProgress = !peerConnection->sendBufferIsEmpty();
   if(!sendingInProgress) {
     onSendComplete();
