@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -59,11 +59,13 @@
 #include "AnnounceTier.h"
 #include "DownloadContext.h"
 #include "bittorrent_helper.h"
+#include "a2functional.h"
+#include "util.h"
 
 namespace aria2 {
 
 TrackerWatcherCommand::TrackerWatcherCommand
-(int32_t cuid, RequestGroup* requestGroup, DownloadEngine* e):
+(cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e):
   Command(cuid),
   _requestGroup(requestGroup),
   e(e)
@@ -81,24 +83,35 @@ bool TrackerWatcherCommand::execute() {
     if(_trackerRequestGroup.isNull()) {
       return true;
     } else if(_trackerRequestGroup->getNumCommand() == 0 ||
-	      _trackerRequestGroup->downloadFinished()) {
+              _trackerRequestGroup->downloadFinished()) {
       return true;
     } else {
       _trackerRequestGroup->setForceHaltRequested(true);
+      e->commands.push_back(this);
       return false;
     }
   }
   if(_btAnnounce->noMoreAnnounce()) {
-    logger->debug("no more announce");
+    if(logger->debug()) {
+      logger->debug("no more announce");
+    }
     return true;
   }
   if(_trackerRequestGroup.isNull()) {
     _trackerRequestGroup = createAnnounce();
     if(!_trackerRequestGroup.isNull()) {
-      std::deque<Command*> commands;
-      _trackerRequestGroup->createInitialCommand(commands, e);
+      std::vector<Command*> commands;
+      try {
+        _trackerRequestGroup->createInitialCommand(commands, e);
+      } catch(RecoverableException& ex) {
+        logger->error(EX_EXCEPTION_CAUGHT, ex);
+        std::for_each(commands.begin(), commands.end(), Deleter());
+        commands.clear();
+      }
       e->addCommand(commands);
-      logger->debug("added tracker request command");
+      if(logger->debug()) {
+        logger->debug("added tracker request command");
+      }
     }
   } else if(_trackerRequestGroup->downloadFinished()){
     try {
@@ -111,7 +124,7 @@ bool TrackerWatcherCommand::execute() {
       logger->error(EX_EXCEPTION_CAUGHT, ex);      
       _btAnnounce->announceFailure();
       if(_btAnnounce->isAllAnnounceFailed()) {
-	_btAnnounce->resetAnnounce();
+        _btAnnounce->resetAnnounce();
       }
     }
     _trackerRequestGroup.reset();
@@ -128,7 +141,7 @@ bool TrackerWatcherCommand::execute() {
 }
 
 std::string TrackerWatcherCommand::getTrackerResponse
-(const RequestGroupHandle& requestGroup)
+(const SharedHandle<RequestGroup>& requestGroup)
 {
   std::stringstream strm;
   unsigned char data[2048];
@@ -150,9 +163,9 @@ void TrackerWatcherCommand::processTrackerResponse
 {
   _btAnnounce->processAnnounceResponse
     (reinterpret_cast<const unsigned char*>(trackerResponse.c_str()),
-				      trackerResponse.size());
+     trackerResponse.size());
   while(!_btRuntime->isHalt() && _btRuntime->lessThanMinPeers()) {
-    PeerHandle peer = _peerStorage->getUnusedPeer();
+    SharedHandle<Peer> peer = _peerStorage->getUnusedPeer();
     if(peer.isNull()) {
       break;
     }
@@ -163,12 +176,16 @@ void TrackerWatcherCommand::processTrackerResponse
     command->setPeerStorage(_peerStorage);
     command->setPieceStorage(_pieceStorage);
     e->commands.push_back(command);
-    logger->debug("CUID#%d - Adding new command CUID#%d", cuid, peer->usedBy());
+    if(logger->debug()) {
+      logger->debug("CUID#%s - Adding new command CUID#%s",
+                    util::itos(cuid).c_str(),
+                    util::itos(peer->usedBy()).c_str());
+    }
   }
 }
 
-RequestGroupHandle TrackerWatcherCommand::createAnnounce() {
-  RequestGroupHandle rg;
+SharedHandle<RequestGroup> TrackerWatcherCommand::createAnnounce() {
+  SharedHandle<RequestGroup> rg;
   if(_btAnnounce->isAnnounceReady()) {
     rg = createRequestGroup(_btAnnounce->getAnnounceUrl());
     _btAnnounce->announceStart(); // inside it, trackers++.
@@ -194,30 +211,36 @@ static bool backupTrackerIsAvailable
   }
 }
 
-RequestGroupHandle
+SharedHandle<RequestGroup>
 TrackerWatcherCommand::createRequestGroup(const std::string& uri)
 {
-  std::deque<std::string> uris;
+  std::vector<std::string> uris;
   uris.push_back(uri);
-  RequestGroupHandle rg(new RequestGroup(getOption()));
-  // If backup tracker is available, only try 2 times for each tracker
-  // and if they all fails, then try next one.
+  SharedHandle<RequestGroup> rg(new RequestGroup(getOption()));
   if(backupTrackerIsAvailable(_requestGroup->getDownloadContext())) {
-    logger->debug("This is multi-tracker announce.");
-    rg->getOption()->put(PREF_MAX_TRIES, "2");
+    if(logger->debug()) {
+      logger->debug("This is multi-tracker announce.");
+    }
   } else {
-    logger->debug("This is single-tracker announce.");
-    rg->getOption()->put(PREF_MAX_TRIES, "5");
+    if(logger->debug()) {
+      logger->debug("This is single-tracker announce.");
+    }
   }
+  // If backup tracker is available, try 2 times for each tracker
+  // and if they all fails, then try next one.
+  rg->getOption()->put(PREF_MAX_TRIES, "2");
   // TODO When dry-run mode becomes available in BitTorrent, set
   // PREF_DRY_RUN=false too.
   rg->getOption()->put(PREF_USE_HEAD, V_FALSE);
-
+  // Setting tracker timeouts
+  rg->setTimeout(rg->getOption()->getAsInt(PREF_BT_TRACKER_TIMEOUT));
+  rg->getOption()->put(PREF_CONNECT_TIMEOUT,
+                       rg->getOption()->get(PREF_BT_TRACKER_CONNECT_TIMEOUT));
   static const std::string TRACKER_ANNOUNCE_FILE("[tracker.announce]");
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(getOption()->getAsInt(PREF_SEGMENT_SIZE),
-			 0,
-			 TRACKER_ANNOUNCE_FILE));
+                         0,
+                         TRACKER_ANNOUNCE_FILE));
   dctx->setDir(A2STR::NIL);
   dctx->getFileEntries().front()->setUris(uris);
   rg->setDownloadContext(dctx);
@@ -225,7 +248,11 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   rg->setDiskWriterFactory(dwf);
   rg->setFileAllocationEnabled(false);
   rg->setPreLocalFileCheckEnabled(false);
-  logger->info("Creating tracker request group GID#%d", rg->getGID());
+  util::removeMetalinkContentTypes(rg);
+  if(logger->info()) {
+    logger->info("Creating tracker request group GID#%s",
+                 util::itos(rg->getGID()).c_str());
+  }
   return rg;
 }
 
