@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,6 +39,7 @@
 
 #include <cassert>
 #include <cstdlib>
+#include <cstring>
 
 #include "util.h"
 
@@ -50,7 +51,16 @@ namespace bitfield {
 // then 0x80 is returned. nbits = 12, then 0xf0 is returned.
 inline unsigned char lastByteMask(size_t nbits)
 {
-  return -256 >> (8-((nbits+7)/8*8-nbits));
+  if(nbits == 0) {
+    return 0;
+  } else {
+    int s = nbits%8;
+    if(s == 0) {
+      return 0xff;
+    } else {
+      return -256 >> s;
+    }
+  }
 }
 
 // Returns true if index-th bits is set. Otherwise returns false.
@@ -105,7 +115,9 @@ inline size_t countSetBit(const unsigned char* bitfield, size_t nbits)
   }
   size_t to = len/size;
   for(size_t i = 0; i < to; ++i) {
-    count += countBit32(*reinterpret_cast<const uint32_t*>(&bitfield[i*size]));
+    uint32_t v;
+    memcpy(&v, &bitfield[i*size], sizeof(v));
+    count += countBit32(v);
   }
   for(size_t i = len-len%size; i < len; ++i) {
     count += countBit32(static_cast<uint32_t>(bitfield[i]));
@@ -115,6 +127,53 @@ inline size_t countSetBit(const unsigned char* bitfield, size_t nbits)
 
 void flipBit(unsigned char* data, size_t length, size_t bitIndex);
 
+// Stores first missing bit index of bitfield to index.  bitfield
+// contains nbits. Returns true if missing bit index is
+// found. Otherwise returns false.
+template<typename Array>
+bool getFirstMissingIndex
+(size_t& index, const Array& bitfield, size_t nbits)
+{
+  const size_t bitfieldLength = (nbits+7)/8;
+  for(size_t i = 0; i < bitfieldLength; ++i) {
+    unsigned char mask = 128;
+    size_t tindex = i*8;
+    for(size_t bi = 0; bi < 8 && tindex < nbits; ++bi, mask >>= 1, ++tindex) {
+      if(bitfield[i] & mask) {
+        index = tindex;
+        return true;
+      }
+    }
+  }
+  return false;
+}
+
+// Appends first at most n set bit index in bitfield to out.  bitfield
+// contains nbits bits.  Returns the number of appended bit indexes.
+template<typename Array, typename OutputIterator>
+size_t getFirstNMissingIndex
+(OutputIterator out, size_t n, const Array& bitfield, size_t nbits)
+{
+  if(n == 0) {
+    return 0;
+  }
+  const size_t origN = n;
+  const size_t bitfieldLength = (nbits+7)/8;
+  for(size_t i = 0; i < bitfieldLength; ++i) {
+    unsigned char mask = 128;
+    size_t tindex = i*8;
+    for(size_t bi = 0; bi < 8 && tindex < nbits; ++bi, mask >>= 1, ++tindex) {
+      if(bitfield[i] & mask) {
+        *out++ = tindex;
+        if(--n == 0) {
+          return origN;
+        }
+      }
+    }
+  }
+  return origN-n;
+}
+
 } // namespace bitfield
 
 } // namespace aria2
