@@ -39,9 +39,9 @@
 
 #include <sys/time.h>
 
+#include <cstdio>
 #include <string>
 #include <utility>
-#include <deque>
 #include <iosfwd>
 #include <ostream>
 #include <numeric>
@@ -62,6 +62,7 @@ class Randomizer;
 class BitfieldMan;
 class BinaryStream;
 class FileEntry;
+class RequestGroup;
 
 #define STRTOLL(X) strtoll(X, reinterpret_cast<char**>(0), 10)
 #define STRTOULL(X) strtoull(X, reinterpret_cast<char**>(0), 10)
@@ -114,20 +115,7 @@ std::string uitos(T value, bool comma = false)
   return str;
 }
 
-template<typename T>
-std::string itos(T value, bool comma = false)
-{
-  bool flag = false;
-  if(value < 0) {
-    flag = true;
-    value = -value;
-  }
-  std::string str = uitos(value, comma);
-  if(flag) {
-    str.insert(str.begin(), '-');
-  }
-  return str;
-}
+std::string itos(int64_t value, bool comma = false);
 
 /**
  * Computes difference in micro-seconds between tv1 and tv2,
@@ -151,19 +139,19 @@ bool endsWith(const std::string& target, const std::string& part);
 
 std::string replace(const std::string& target, const std::string& oldstr, const std::string& newstr);
 
-std::string urlencode(const unsigned char* target, size_t len);
+std::string percentEncode(const unsigned char* target, size_t len);
 
-std::string urlencode(const std::string& target);
+std::string percentEncode(const std::string& target);
 
 bool inRFC3986ReservedChars(const char c);
 
 bool inRFC3986UnreservedChars(const char c);
 
-std::string urldecode(const std::string& target);
+std::string percentDecode(const std::string& target);
 
-std::string torrentUrlencode(const unsigned char* target, size_t len);
+std::string torrentPercentEncode(const unsigned char* target, size_t len);
 
-std::string torrentUrlencode(const std::string& target);
+std::string torrentPercentEncode(const std::string& target);
 
 std::string toHex(const unsigned char* src, size_t len);
 
@@ -212,7 +200,9 @@ void parsePrioritizePieceRange
  size_t pieceLength,
  uint64_t defaultSize = 1048576 /* 1MiB */);
 
-// this function temporarily put here
+// Converts ISO/IEC 8859-1 string src to utf-8.
+std::string iso8859ToUtf8(const std::string& src);
+
 std::string getContentDispositionFilename(const std::string& header);
 
 std::string randomAlpha(size_t length,
@@ -222,7 +212,7 @@ std::string toUpper(const std::string& src);
 
 std::string toLower(const std::string& src);
 
-bool isNumbersAndDotsNotation(const std::string& name);
+bool isNumericHost(const std::string& name);
 
 void setGlobalSignalHandler(int signal, void (*handler)(int), int flags);
 
@@ -253,11 +243,17 @@ void sleep(long seconds);
 void usleep(long microseconds);
   
 bool isNumber(const std::string& what);
+
+bool isDigit(const char c);
+
+bool isHexDigit(const char c);
+
+bool isHexDigit(const std::string& s);
   
 bool isLowercase(const std::string& what);
   
 bool isUppercase(const std::string& what);
-  
+
 /**
  * Converts alphabets to unsigned int, assuming alphabets as a base 26
  * integer and 'a' or 'A' is 0.
@@ -289,7 +285,7 @@ std::string htmlEscape(const std::string& src);
 template<typename InputIterator>
 std::string joinPath(InputIterator first, InputIterator last)
 {
-  std::deque<std::string> elements;
+  std::vector<std::string> elements;
   for(;first != last; ++first) {
     if(*first == "..") {
       if(!elements.empty()) {
@@ -317,7 +313,8 @@ std::map<size_t, std::string> createIndexPathMap(std::istream& i);
  */
 template<typename OutputIterator>
 OutputIterator split(const std::string& src, OutputIterator out,
-                     const std::string& delims, bool doTrim = false)
+                     const std::string& delims, bool doTrim = false,
+                     bool allowEmpty = false)
 {
   std::string::size_type p = 0;
   while(1) {
@@ -327,7 +324,7 @@ OutputIterator split(const std::string& src, OutputIterator out,
       if(doTrim) {
         term = util::trim(term);
       }
-      if(!term.empty()) {
+      if(allowEmpty || !term.empty()) {
         *out = term;
         ++out;
       }
@@ -338,7 +335,7 @@ OutputIterator split(const std::string& src, OutputIterator out,
       term = util::trim(term);
     }
     p = np+1;
-    if(!term.empty()) {
+    if(allowEmpty || !term.empty()) {
       *out = term;
       ++out;
     }
@@ -368,13 +365,36 @@ std::string applyDir(const std::string& dir, const std::string& relPath);
 // basename contains dir component. This should be avoided.  This
 // function is created to fix these issues.  This function expects src
 // should be non-percent-encoded basename.  Currently, this function
-// replaces '/' and '\' with '_'.
+// replaces '/' with '_' and result string is passed to escapePath()
+// function and its result is returned.
 std::string fixTaintedBasename(const std::string& src);
 
 // Generates 20 bytes random key and store it to the address pointed
 // by key.  Caller must allocate at least 20 bytes for generated key.
 void generateRandomKey(unsigned char* key);
 
+// Returns true is given numeric ipv4addr is in Private Address Space.
+bool inPrivateAddress(const std::string& ipv4addr);
+
+// Returns true if s contains directory traversal path component such
+// as '..' or it contains null or control character which may fool
+// user.
+bool detectDirTraversal(const std::string& s);
+
+// Replaces null(0x00) and control character(0x01-0x1f) with '_'. If
+// __MINGW32__ is defined, following characters are also replaced with
+// '_': '"', '*', ':', '<', '>', '?', '\', '|'.
+std::string escapePath(const std::string& s);
+
+// Stores network address of numeric IPv4 address ip using CIDR bits
+// into in.  On success, returns true. Otherwise returns false.
+bool getCidrPrefix(struct in_addr& in, const std::string& ip, int bits);
+
+// Returns true if ip1 and ip2 are in the same CIDR block.
+bool inSameCidrBlock(const std::string& ip1, const std::string& ip2, int bits);
+
+void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group);
+
 } // namespace util
 
 } // namespace aria2
