@@ -30,7 +30,7 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testRandomAlpha);
   CPPUNIT_TEST(testToUpper);
   CPPUNIT_TEST(testToLower);
-  CPPUNIT_TEST(testUrldecode);
+  CPPUNIT_TEST(testPercentDecode);
   CPPUNIT_TEST(testGetRealSize);
   CPPUNIT_TEST(testAbbrevSize);
   CPPUNIT_TEST(testToStream);
@@ -50,7 +50,7 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testItos);
   CPPUNIT_TEST(testUitos);
   CPPUNIT_TEST(testNtoh64);
-  CPPUNIT_TEST(testUrlencode);
+  CPPUNIT_TEST(testPercentEncode);
   CPPUNIT_TEST(testHtmlEscape);
   CPPUNIT_TEST(testJoinPath);
   CPPUNIT_TEST(testParseIndexPath);
@@ -61,6 +61,10 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testApplyDir);
   CPPUNIT_TEST(testFixTaintedBasename);
   CPPUNIT_TEST(testIsNumericHost);
+  CPPUNIT_TEST(testDetectDirTraversal);
+  CPPUNIT_TEST(testEscapePath);
+  CPPUNIT_TEST(testGetCidrPrefix);
+  CPPUNIT_TEST(testInSameCidrBlock);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -79,7 +83,7 @@ public:
   void testRandomAlpha();
   void testToUpper();
   void testToLower();
-  void testUrldecode();
+  void testPercentDecode();
   void testGetRealSize();
   void testAbbrevSize();
   void testToStream();
@@ -99,7 +103,7 @@ public:
   void testItos();
   void testUitos();
   void testNtoh64();
-  void testUrlencode();
+  void testPercentEncode();
   void testHtmlEscape();
   void testJoinPath();
   void testParseIndexPath();
@@ -110,6 +114,10 @@ public:
   void testApplyDir();
   void testFixTaintedBasename();
   void testIsNumericHost();
+  void testDetectDirTraversal();
+  void testEscapePath();
+  void testGetCidrPrefix();
+  void testInSameCidrBlock();
 };
 
 
@@ -154,11 +162,11 @@ void UtilTest::testSplit() {
 }
 
 void UtilTest::testSplit_many() {
-  std::deque<std::string> v1;
+  std::vector<std::string> v1;
   util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
               ";", true);
-  CPPUNIT_ASSERT_EQUAL(3, (int)v1.size());
-  std::deque<std::string>::iterator itr = v1.begin();
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
+  std::vector<std::string>::iterator itr = v1.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string("name2=value2"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string("name3=value3"), *itr++);
@@ -167,11 +175,28 @@ void UtilTest::testSplit_many() {
 
   util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
               ";", false);
-  CPPUNIT_ASSERT_EQUAL(3, (int)v1.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
   itr = v1.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string(" name2=value2"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string(" name3=value3"), *itr++);
+
+  v1.clear();
+
+  util::split("k=v", std::back_inserter(v1), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("k=v"), v1[0]);
+
+  v1.clear();
+
+  util::split(" ", std::back_inserter(v1), ";", true, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
+  CPPUNIT_ASSERT_EQUAL(std::string(""), v1[0]);
+
+  v1.clear();
+
+  util::split(" ", std::back_inserter(v1), ";", true);
+  CPPUNIT_ASSERT_EQUAL((size_t)0, v1.size());
 }
 
 void UtilTest::testEndsWith() {
@@ -276,7 +301,8 @@ void UtilTest::testGetContentDispositionFilename() {
   CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2"), util::getContentDispositionFilename(h8));
 
   std::string h9 = "attachment; filename=\"aria2.tar.bz2; creation-date=20 Jun 2007 00:00:00 GMT\"";
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2; creation-date=20 Jun 2007 00:00:00 GMT"), util::getContentDispositionFilename(h9));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2; creation-date=20 Jun 2007 00:00:00 GMT"),
+                       util::getContentDispositionFilename(h9));
 
   std::string h10 = "attachment; filename=";
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::getContentDispositionFilename(h10));
@@ -285,16 +311,95 @@ void UtilTest::testGetContentDispositionFilename() {
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::getContentDispositionFilename(h11));
 
   std::string filenameWithDir = "attachment; filename=dir/file";
-  CPPUNIT_ASSERT_EQUAL(std::string("file"),
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
                        util::getContentDispositionFilename(filenameWithDir));
 
-  std::string parentDir = "attachment; filename=..";
-  CPPUNIT_ASSERT_EQUAL(std::string(),
-                       util::getContentDispositionFilename(parentDir));
+  std::string semicolonInside = "attachment; filename=\"foo;bar\"";
+  CPPUNIT_ASSERT_EQUAL(std::string("foo;bar"),
+                       util::getContentDispositionFilename(semicolonInside));
 
-  std::string currentDir = "attachment; filename=.";
-  CPPUNIT_ASSERT_EQUAL(std::string(),
-                       util::getContentDispositionFilename(currentDir));
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename("filename=\"%2E%2E%2Ffoo.html\""));
+
+  // RFC2231 Section4
+  std::string extparam2 = "filename*=''aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2"),
+                       util::getContentDispositionFilename(extparam2));
+  std::string extparam3 = "filename*='''";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam3));
+  std::string extparam4 = "filename*='aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam4));
+  std::string extparam5 = "filename*='''aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam5));
+  std::string extparam6 = "filename*";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam6));
+  std::string extparam7 = "filename*=UTF-8''aria2;filename=hello%20world";
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2"),
+                       util::getContentDispositionFilename(extparam7));
+  std::string extparam8 = "filename=aria2;filename*=UTF-8''hello%20world";
+  CPPUNIT_ASSERT_EQUAL(std::string("hello world"),
+                       util::getContentDispositionFilename(extparam8));
+  std::string extparam9 = "filename*=ISO-8859-1''%A3";
+  std::string extparam9ans;
+  extparam9ans += 0xc2;
+  extparam9ans += 0xa3;
+  CPPUNIT_ASSERT_EQUAL(extparam9ans,
+                       util::getContentDispositionFilename(extparam9));
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename("filename*=UTF-8''foo%2F.html"));
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo.html"),
+     util::getContentDispositionFilename("filename*=UTF-8'';filename=\"foo.html\""));
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename("filename*=UTF-8''%2E%2E%2Ffoo.html"));
+
+  // Tests from http://greenbytes.de/tech/tc2231/
+  // attwithasciifnescapedchar
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo.html"),
+     util::getContentDispositionFilename("filename=\"f\\oo.html\""));
+  // attwithasciifilenameucase
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo.html"),
+     util::getContentDispositionFilename("FILENAME=\"foo.html\""));
+  // attwithisofn2231iso
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename*=iso-8859-1''foo-%E4.html"));
+  // attwithfn2231utf8
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä-€.html"),
+     util::getContentDispositionFilename
+     ("filename*=UTF-8''foo-%c3%a4-%e2%82%ac.html"));
+  // attwithfn2231utf8-bad
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename
+     ("filename*=iso-8859-1''foo-%c3%a4-%e2%82%ac.html"));
+  // attwithfn2231ws1
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename("filename *=UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231ws2
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename*= UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231ws3
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename* =UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231quot
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename
+     ("filename*=\"UTF-8''foo-%c3%a4.html\""));
 }
 
 class Printer {
@@ -325,25 +430,25 @@ void UtilTest::testToLower() {
   CPPUNIT_ASSERT_EQUAL(upp, util::toLower(src));
 }
 
-void UtilTest::testUrldecode() {
+void UtilTest::testPercentDecode() {
   std::string src = "http://aria2.sourceforge.net/aria2%200.7.0%20docs.html";
   CPPUNIT_ASSERT_EQUAL(std::string("http://aria2.sourceforge.net/aria2 0.7.0 docs.html"),
-                       util::urldecode(src));
+                       util::percentDecode(src));
 
   std::string src2 = "aria2+aria2";
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2+aria2"), util::urldecode(src2));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2+aria2"), util::percentDecode(src2));
 
   std::string src3 = "%5t%20";
-  CPPUNIT_ASSERT_EQUAL(std::string("%5t "), util::urldecode(src3));
+  CPPUNIT_ASSERT_EQUAL(std::string("%5t "), util::percentDecode(src3));
 
   std::string src4 = "%";
-  CPPUNIT_ASSERT_EQUAL(std::string("%"), util::urldecode(src4));
+  CPPUNIT_ASSERT_EQUAL(std::string("%"), util::percentDecode(src4));
   
   std::string src5 = "%3";
-  CPPUNIT_ASSERT_EQUAL(std::string("%3"), util::urldecode(src5));
+  CPPUNIT_ASSERT_EQUAL(std::string("%3"), util::percentDecode(src5));
 
   std::string src6 = "%2f";
-  CPPUNIT_ASSERT_EQUAL(std::string("/"), util::urldecode(src6));
+  CPPUNIT_ASSERT_EQUAL(std::string("/"), util::percentDecode(src6));
 }
 
 void UtilTest::testGetRealSize()
@@ -684,8 +789,14 @@ void UtilTest::testItos()
   }
   {
     int64_t i = INT64_MAX;
-    CPPUNIT_ASSERT_EQUAL(std::string("9,223,372,036,854,775,807"), util::itos(i, true));
-  }  
+    CPPUNIT_ASSERT_EQUAL(std::string("9,223,372,036,854,775,807"),
+                         util::itos(i, true));
+  }
+  {
+    int64_t i = INT64_MIN;
+    CPPUNIT_ASSERT_EQUAL(std::string("-9,223,372,036,854,775,808"),
+                         util::itos(i, true));
+  }
 }
 
 void UtilTest::testUitos()
@@ -713,20 +824,20 @@ void UtilTest::testNtoh64()
 #endif // !WORDS_BIGENDIAN
 }
 
-void UtilTest::testUrlencode()
+void UtilTest::testPercentEncode()
 {
   CPPUNIT_ASSERT_EQUAL
     (std::string("%3A%2F%3F%23%5B%5D%40%21%25%26%27%28%29%2A%2B%2C%3B%3D"),
-     util::urlencode(":/?#[]@!%&'()*+,;="));
+     util::percentEncode(":/?#[]@!%&'()*+,;="));
 
   std::string unreserved =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
     "abcdefghijklmnopqrstuvwxyz"
     "0123456789"
     "-._~";
-  CPPUNIT_ASSERT_EQUAL(unreserved, util::urlencode(unreserved));
+  CPPUNIT_ASSERT_EQUAL(unreserved, util::percentEncode(unreserved));
 
-  CPPUNIT_ASSERT_EQUAL(std::string("1%5EA%20"), util::urlencode("1^A "));
+  CPPUNIT_ASSERT_EQUAL(std::string("1%5EA%20"), util::percentEncode("1^A "));
 }
 
 void UtilTest::testHtmlEscape()
@@ -740,33 +851,28 @@ void UtilTest::testJoinPath()
   const std::string dir1dir2file[] = { "dir1", "dir2", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("dir1/dir2/file"),
-     util::joinPath(&dir1dir2file[0],
-                    &dir1dir2file[arrayLength(dir1dir2file)]));
+     util::joinPath(vbegin(dir1dir2file), vend(dir1dir2file)));
 
   const std::string dirparentfile[] = { "dir", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
-     util::joinPath(&dirparentfile[0],
-                    &dirparentfile[arrayLength(dirparentfile)]));
+     util::joinPath(vbegin(dirparentfile), vend(dirparentfile)));
 
   const std::string dirparentparentfile[] = { "dir", "..", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
-     util::joinPath(&dirparentparentfile[0],
-                    &dirparentparentfile[arrayLength(dirparentparentfile)]));
+     util::joinPath(vbegin(dirparentparentfile), vend(dirparentparentfile)));
 
   const std::string dirdotfile[] = { "dir", ".", "file" };
   CPPUNIT_ASSERT_EQUAL(std::string("dir/file"),
-                       util::joinPath(&dirdotfile[0],
-                                      &dirdotfile[arrayLength(dirdotfile)]));
+                       util::joinPath(vbegin(dirdotfile), vend(dirdotfile)));
 
   const std::string empty[] = {};
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::joinPath(&empty[0], &empty[0]));
 
   const std::string parentdot[] = { "..", "." };
   CPPUNIT_ASSERT_EQUAL(std::string(""),
-                       util::joinPath(&parentdot[0],
-                                      &parentdot[arrayLength(parentdot)]));
+                       util::joinPath(vbegin(parentdot), vend(parentdot)));
 }
 
 void UtilTest::testParseIndexPath()
@@ -917,8 +1023,11 @@ void UtilTest::testApplyDir()
 void UtilTest::testFixTaintedBasename()
 {
   CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a/b"));
+#ifdef __MINGW32__
   CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a\\b"));
-  CPPUNIT_ASSERT_EQUAL(std::string("a__b"), util::fixTaintedBasename("a\\/b"));
+#else // !__MINGW32__
+  CPPUNIT_ASSERT_EQUAL(std::string("a\\b"), util::fixTaintedBasename("a\\b"));
+#endif // !__MINGW32__
 }
 
 void UtilTest::testIsNumericHost()
@@ -928,4 +1037,65 @@ void UtilTest::testIsNumericHost()
   CPPUNIT_ASSERT(util::isNumericHost("::1"));
 }
 
+void UtilTest::testDetectDirTraversal()
+{
+  CPPUNIT_ASSERT(util::detectDirTraversal("/foo"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("./foo"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("../foo"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("foo/../bar"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("foo/./bar"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("foo/."));
+  CPPUNIT_ASSERT(util::detectDirTraversal("foo/.."));
+  CPPUNIT_ASSERT(util::detectDirTraversal("."));
+  CPPUNIT_ASSERT(util::detectDirTraversal(".."));
+  CPPUNIT_ASSERT(util::detectDirTraversal("/"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("foo/"));
+  CPPUNIT_ASSERT(util::detectDirTraversal("\t"));
+  CPPUNIT_ASSERT(!util::detectDirTraversal("foo/bar"));
+  CPPUNIT_ASSERT(!util::detectDirTraversal("foo"));
+}
+
+void UtilTest::testEscapePath()
+{
+  CPPUNIT_ASSERT_EQUAL(std::string("foo_bar__"),
+                       util::escapePath(std::string("foo")+(char)0x00+
+                                        std::string("bar")+(char)0x00+
+                                        (char)0x01));
+#ifdef __MINGW32__
+  CPPUNIT_ASSERT_EQUAL(std::string("foo_bar"), util::escapePath("foo\\bar"));
+#else // !__MINGW32__
+  CPPUNIT_ASSERT_EQUAL(std::string("foo\\bar"), util::escapePath("foo\\bar"));
+#endif // !__MINGW32__
+}
+
+void UtilTest::testGetCidrPrefix()
+{
+  struct in_addr in;
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "192.168.0.1", 16));
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.0"), std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "192.168.255.255", 17));
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.128.0"),std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "192.168.128.1", 16));
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.0"), std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "192.168.0.1", 32));
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "192.168.0.1", 0));
+  CPPUNIT_ASSERT_EQUAL(std::string("0.0.0.0"), std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(util::getCidrPrefix(in, "10.10.1.44", 27));
+  CPPUNIT_ASSERT_EQUAL(std::string("10.10.1.32"), std::string(inet_ntoa(in)));
+
+  CPPUNIT_ASSERT(!util::getCidrPrefix(in, "::1", 32));
+}
+
+void UtilTest::testInSameCidrBlock()
+{
+  CPPUNIT_ASSERT(util::inSameCidrBlock("192.168.128.1", "192.168.0.1", 16));
+  CPPUNIT_ASSERT(!util::inSameCidrBlock("192.168.128.1", "192.168.0.1", 17));
+}
+
 } // namespace aria2
